{%- block header -%}{%- endblock -%}
{{ title }}

{{ body }}
{%- block inset -%}{%- endblock -%}
{{ comment_char }} Please enter the content for your new bug, the first line will be used for
{{ comment_char }} the title.  Lines beginning with '{{ comment_char }}' will be ignored
{%- block footer -%}{%- endblock -%}
